------------------------------------------
---  Copyright HDRsoft - www.hdrsoft.com   
------------------------------------------

local LrApplication = import 'LrApplication'
local LrFileUtils = import 'LrFileUtils'
local LrPathUtils = import 'LrPathUtils'
local LrErrors = import 'LrErrors'
local LrTasks = import 'LrTasks'
local prefs = import 'LrPrefs'.prefsForPlugin() 
local LrLogger = import 'LrLogger'

local myLogger = LrLogger('PhotomatixLogger')
myLogger:disable("print") 


CreateHdrUtils = {}


function CreateHdrUtils.GetRegAppPath ( )
	local appPath=LrPathUtils.child(_PLUGIN.path, "app")

	local clProgName="Merge32Utils"
	if (MAC_ENV) then
		clProgName="MergeToHDR"
	end

	appPath=LrPathUtils.child(appPath, clProgName)
	
	if (WIN_ENV) then
		appPath=LrPathUtils.addExtension(appPath, "exe")
	end
	
	if not LrFileUtils.exists(appPath) then
		return false  -- Cannot tell
	end

	return appPath
end


function CreateHdrUtils.Validate (licenseKey)

	local regOK=false
	
	local appPath=CreateHdrUtils.GetRegAppPath()

	if (appPath) then
		
		local CommandLine=string.format('\"%s\" -kv ', appPath)
		
		if (licenseKey~=nil) then
			myLogger:trace(string.format('License Key is:  %s', licenseKey))
			if (licenseKey~="") then
				CommandLine=string.format('%s %s',CommandLine, licenseKey)			
			end
		end

		myLogger:trace(string.format('command is  %s', CommandLine))
		
		local retour=LrTasks.execute(CommandLine)
		myLogger:trace(string.format('After LrTasks.execute - retour is: %d', retour))
		
		if (retour==0) then
			regOK=true
		end
	
	end
	
	return regOK

end


function CreateHdrUtils.IsFloatTiff(fileName)
	myLogger:trace(string.format('Check: fileName=%s',fileName))

	local appPath=CreateHdrUtils.GetRegAppPath()
	
	if not appPath then
		return false
	end

	local cmd
	if (WIN_ENV) then
		cmd = string.format('\"%s -tf \"%s\"\"', appPath, fileName)
	else
		cmd=string.format('\"%s\" -tf \"%s\"', appPath, fileName)
	end
	
	myLogger:trace(string.format('Running: fileName=%s',cmd))
	
	retour=LrTasks.execute(cmd)
	myLogger:trace(string.format('Returned: %s',retour))
	
	local ReturnedValWhenHalfFloat=1
	if (MAC_ENV) then
		ReturnedValWhenHalfFloat=0
	end

	if retour == ReturnedValWhenHalfFloat then
		return true
	else
		return false
	end
end
